.. _change_scores:

Change scores
=============

.. currentmodule:: skchange.change_scores

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    ChangeScore
    ContinuousLinearTrendScore
    CUSUM
    ESACScore
    MultivariateGaussianScore

Utility functions
-----------------

.. currentmodule:: skchange.change_scores

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    to_change_score
